import 'package:flutter/material.dart';
import '../../base-uikit/textfield/clearButton_textfield.dart';
import '../../base-uikit/textfield/textfield_container.dart';

/// 文本框(常用于：登录用户名、密码文本框，在原本基础上增加了 图片 选中状态的判断)
class IconTextField extends StatefulWidget {
  final String? text;
  final String? placeholder;

  /// prefix icon
  final bool Function(String currentText)? prefixIconSelectedCallback;
  final String prefixIconNormalImageName;
  final String prefixIconSelectedImageName;
  final String? package;

  final TextStyle? style;
  final bool? autofocus;
  final bool? obscureText;
  final TextInputType? keyboardType;
  final TextEditingController? controller;
  final bool? showClear;
  final TextInputAction? textInputAction;
  final FocusNode? focusNode;
  final ValueChanged<String>? onSubmitted;

  IconTextField({
    Key? key,
    this.text,
    this.placeholder,

    /// prefix icon
    this.prefixIconSelectedCallback,
    required this.prefixIconNormalImageName,
    required this.prefixIconSelectedImageName,
    this.package,
    this.style,
    this.autofocus = false,
    this.obscureText = false,
    this.keyboardType,
    this.controller,
    this.showClear = false,
    this.textInputAction,
    this.focusNode,
    this.onSubmitted,
  }) : super(
          key: key,
        );

  @override
  State<StatefulWidget> createState() {
    return IconTextFieldState();
  }
}

class IconTextFieldState extends State<IconTextField> {
  late bool _prefixIconSelected;
  late String _text;
  late TextEditingController _controller;

  @override
  void initState() {
    super.initState();

    _text = widget.text ?? '';
    _controller = widget.controller ?? TextEditingController();

    _prefixIconSelected = false;
    if (widget.prefixIconSelectedCallback != null) {
      _prefixIconSelected = widget.prefixIconSelectedCallback!(_text);
    }
  }

  @override
  Widget build(BuildContext context) {
    return CJTextFieldContainer(
      height: 44,
      backgroundColor: Colors.transparent,
      cornerRadius: 16,
      borderWidth: 0.6,
      borderColor: Color(0xff323334),
      textFieldWidget: _textField(),
      prefixWidget: _prefixIcon(),
      suffixWidget: SizedBox(width: 5),
    );
  }

  Widget _textField() {
    return CJClearButtonTextField(
      placeholder: widget.placeholder,
      text: widget.text,
      style: widget.style,
      textInputAction: widget.textInputAction,
      controller: _controller,
      onChanged: (String string) {
        if (widget.prefixIconSelectedCallback != null) {
          _prefixIconSelected = widget.prefixIconSelectedCallback!(string);
        }
        setState(() {});
      },
      onSubmitted: widget.onSubmitted,
    );
  }

  Widget _prefixIcon() {
    String assetName = !_prefixIconSelected
        ? widget.prefixIconNormalImageName
        : widget.prefixIconSelectedImageName;
    return Row(
      children: <Widget>[
        SizedBox(width: 5),
        Image.asset(
          assetName,
          width: 14.0,
          height: 15.0,
          package: widget.package,
        ),
        SizedBox(width: 5),
      ],
    );
  }
}
